@@ -35,7 +35,7 @@ Gtk::Window* do_colorsel()
 Example_ColorSel::Example_ColorSel()
 : m_VBox(false, 8),
   m_Button("_Change the above color", true),
-  m_Alignment(1.0, 0.5, 0.0, 0.0)
+  m_Alignment(Gtk::ALIGN_RIGHT, Gtk::ALIGN_BOTTOM, 0.0, 0.0)
 {
   set_title("Color Selection");
   set_border_width(8);
@@ -67,7 +67,7 @@ Example_ColorSel::Example_ColorSel()
 
   m_Alignment.add(m_Button);
 
-  m_VBox.pack_start(m_Alignment,Gtk::SHRINK);
+  m_VBox.pack_start(m_Alignment,Gtk::PACK_SHRINK);
 
   m_Button.signal_clicked().connect(SigC::slot(*this, &Example_ColorSel::on_button_clicked));
 
