@@ -13,7 +13,7 @@
  * to clear the area.
  */
 
-#include "gtkmm.h"
+#include <gtkmm.h>
 
 class Example_DrawingArea : public Gtk::Window
 {
@@ -29,7 +29,7 @@ protected:
   bool on_drawingarea_scribble_motion_notify_event(GdkEventMotion* event);
   bool on_drawingarea_scribble_button_press_event(GdkEventButton* event);
 
-  void scribble_draw_brush(gdouble x, gdouble y);
+  void scribble_draw_brush(int x, int y);
 
   //Member widgets:
   Gtk::Frame m_Frame_Checkerboard, m_Frame_Scribble;
@@ -47,7 +47,8 @@ Gtk::Window* do_drawingarea()
 }
 
 Example_DrawingArea::Example_DrawingArea()
-: m_VBox(false, 8)
+:
+  m_VBox(false, 8)
 {
   set_title("Drawing Area");
   set_border_width(8);
@@ -58,9 +59,8 @@ Example_DrawingArea::Example_DrawingArea()
   /*
    * Create the checkerboard area
    */
-
   m_Label_Checkerboard.set_markup("<u>Checkerboard pattern</u>");
-  m_VBox.pack_start(m_Label_Checkerboard, Gtk::SHRINK);
+  m_VBox.pack_start(m_Label_Checkerboard, Gtk::PACK_SHRINK);
 
   m_Frame_Checkerboard.set_shadow_type(Gtk::SHADOW_IN);
   m_VBox.pack_start(m_Frame_Checkerboard);
@@ -72,13 +72,11 @@ Example_DrawingArea::Example_DrawingArea()
   m_DrawingArea_Checkerboard.signal_expose_event().connect(
       SigC::slot(*this, &Example_DrawingArea::on_drawingarea_checkerboard_expose_event));
 
-
   /*
    * Create the scribble area
    */
-
   m_Label_Scribble.set_markup("<u>Scribble area</u>");
-  m_VBox.pack_start(m_Label_Scribble, Gtk::SHRINK);
+  m_VBox.pack_start(m_Label_Scribble, Gtk::PACK_SHRINK);
 
   m_Frame_Scribble.set_shadow_type(Gtk::SHADOW_IN);
   m_VBox.pack_start(m_Frame_Scribble);
@@ -100,14 +98,12 @@ Example_DrawingArea::Example_DrawingArea()
       SigC::slot(*this, &Example_DrawingArea::on_drawingarea_scribble_button_press_event));
 
   /* Ask to receive events the drawing area doesn't normally
-   * subscribe to
+   * subscribe to.
    */
-  m_DrawingArea_Scribble.set_events(m_DrawingArea_Scribble.get_events()
-	     | Gdk::LEAVE_NOTIFY_MASK
-	     | Gdk::BUTTON_PRESS_MASK
-	     | Gdk::POINTER_MOTION_MASK
-	     | Gdk::POINTER_MOTION_HINT_MASK);
-
+  m_DrawingArea_Scribble.add_events(Gdk::LEAVE_NOTIFY_MASK |
+                                    Gdk::BUTTON_PRESS_MASK |
+                                    Gdk::POINTER_MOTION_MASK |
+                                    Gdk::POINTER_MOTION_HINT_MASK);
   show_all();
 }
 
@@ -115,7 +111,7 @@ Example_DrawingArea::~Example_DrawingArea()
 {
 }
 
-bool Example_DrawingArea::on_drawingarea_checkerboard_expose_event(GdkEventExpose* event)
+bool Example_DrawingArea::on_drawingarea_checkerboard_expose_event(GdkEventExpose*)
 {
   enum { CHECK_SIZE = 10, SPACING = 2 };
 
@@ -183,34 +179,36 @@ bool Example_DrawingArea::on_drawingarea_checkerboard_expose_event(GdkEventExpos
 
 bool Example_DrawingArea::on_drawingarea_scribble_expose_event(GdkEventExpose* event)
 {
- /* We use the "foreground GC" for the widget since it already exists,
+  /* We use the "foreground GC" for the widget since it already exists,
    * but honestly any GC would work. The only thing to worry about
    * is whether the GC has an inappropriate clip region set.
    */
-
-  m_DrawingArea_Scribble.get_window()->draw_drawable(m_DrawingArea_Scribble.get_style()->get_fg_gc(m_DrawingArea_Scribble.get_state()),
-		     m_refPixmap_Scribble,
-		     /* Only copy the area that was exposed. */
-		     event->area.x, event->area.y,
-		     event->area.x, event->area.y,
-		     event->area.width, event->area.height);
+  m_DrawingArea_Scribble.get_window()->draw_drawable(
+      m_DrawingArea_Scribble.get_style()->get_fg_gc(m_DrawingArea_Scribble.get_state()),
+      m_refPixmap_Scribble,
+      // Only copy the area that was exposed:
+      event->area.x, event->area.y,
+      event->area.x, event->area.y,
+      event->area.width, event->area.height);
 
   return false;
 }
 
-bool Example_DrawingArea::on_drawingarea_scribble_configure_event(GdkEventConfigure* event)
+bool Example_DrawingArea::on_drawingarea_scribble_configure_event(GdkEventConfigure*)
 {
-  m_refPixmap_Scribble = Gdk::Pixmap::create(m_DrawingArea_Scribble.get_window(),
-			   m_DrawingArea_Scribble.get_allocation().width,
-			   m_DrawingArea_Scribble.get_allocation().height,
-			   -1);
+  m_refPixmap_Scribble = Gdk::Pixmap::create(
+      m_DrawingArea_Scribble.get_window(),
+      m_DrawingArea_Scribble.get_allocation().width,
+      m_DrawingArea_Scribble.get_allocation().height,
+      -1);
 
   /* Initialize the pixmap to white */
-  m_refPixmap_Scribble->draw_rectangle(m_DrawingArea_Scribble.get_style()->get_white_gc(),
-		      true,
-		      0, 0,
-		      m_DrawingArea_Scribble.get_allocation().width,
-		      m_DrawingArea_Scribble.get_allocation().height);
+  m_refPixmap_Scribble->draw_rectangle(
+      m_DrawingArea_Scribble.get_style()->get_white_gc(),
+      true,
+      0, 0,
+      m_DrawingArea_Scribble.get_allocation().width,
+      m_DrawingArea_Scribble.get_allocation().height);
 
   /* We've handled the configure event, no need for further processing. */
   return true;
@@ -218,65 +216,65 @@ bool Example_DrawingArea::on_drawingarea_scribble_configure_event(GdkEventConfig
 
 bool Example_DrawingArea::on_drawingarea_scribble_motion_notify_event(GdkEventMotion* event)
 {
-  if(m_refPixmap_Scribble.is_null())
-    return false; /* paranoia check, in case we haven't gotten a configure event */
+  if(!m_refPixmap_Scribble)
+    return false; // paranoia check, in case we haven't gotten a configure event
 
-  /* This call is very important; it requests the next motion event.
-   * If you don't call gdk_window_get_pointer() you'll only get
-   * a single motion event. The reason is that we specified
-   * Gdk::POINTER_MOTION_HINT_MASK to gtk_widget_set_events().
-   * If we hadn't specified that, we could just use event->x, event->y
-   * as the pointer location. But we'd also get deluged in events.
-   * By requesting the next event as we handle the current one,
-   * we avoid getting a huge number of events faster than we
-   * can cope.
+  /* This call is very important; it requests the next motion event.  If you
+   * don't call Gdk::Window::get_pointer() you'll only get a single motion
+   * event.  The reason is that we specified Gdk::POINTER_MOTION_HINT_MASK to
+   * Gtk::Widget::add_events().  If we hadn't specified that, we could just use
+   * event->x, event->y as the pointer location. But we'd also get deluged in
+   * events.  By requesting the next event as we handle the current one, we
+   * avoid getting a huge number of events faster than we can cope.
    */
   if(event && event->window)
   {
-    Glib::RefPtr<Gdk::Window> refWindow =
-        Glib::wrap((GdkWindowObject*) event->window, true); //true = take_copy.
+    const Glib::RefPtr<Gdk::Window> refWindow =
+        Glib::wrap((GdkWindowObject*) event->window, true); // true == take_copy
 
     if(refWindow)
     {
-      int x = 0;
-      int y = 0;
-      Gdk::ModifierType state;
+      int x = 0, y = 0;
+      Gdk::ModifierType state = Gdk::ModifierType(0);
+
       refWindow->get_pointer(x, y, state);
 
-      if (state & Gdk::BUTTON1_MASK)
+      if((state & Gdk::BUTTON1_MASK) != 0)
         scribble_draw_brush(x, y);
     }
   }
 
-  /* We've handled it, stop processing */
+  // We've handled it, stop processing.
   return true;
 }
 
 bool Example_DrawingArea::on_drawingarea_scribble_button_press_event(GdkEventButton* event)
 {
-  if(m_refPixmap_Scribble.is_null())
-    return false; /* paranoia check, in case we haven't gotten a configure event */
+  if(!m_refPixmap_Scribble)
+    return false; // paranoia check, in case we haven't gotten a configure event
 
-  if (event->button == 1)
-    scribble_draw_brush(event->x, event->y);
+  if(event->button == 1)
+    scribble_draw_brush(int(event->x), int(event->y));
 
-  /* We've handled the event, stop processing */
+  // We've handled the event, stop processing.
   return true;
 }
 
-/* Draw a rectangle on the screen */
-void Example_DrawingArea::scribble_draw_brush(gdouble x, gdouble y)
-{;
-  Gdk::Rectangle update_rect((gint)(x - 3), (gint)(y - 3), 6, 6);
+/* Draw a rectangle on the screen.
+ */
+void Example_DrawingArea::scribble_draw_brush(int x, int y)
+{
+  const Gdk::Rectangle update_rect (x - 3, y - 3, 6, 6);
 
-  /* Paint to the pixmap, where we store our state */
-  m_refPixmap_Scribble->draw_rectangle(m_DrawingArea_Scribble.get_style()->get_black_gc(),
-		      true,
-		      update_rect.get_x(), update_rect.get_y(),
-		      update_rect.get_width(), update_rect.get_height());
+  // Paint to the pixmap, where we store our state.
+  //
+  m_refPixmap_Scribble->draw_rectangle(
+      m_DrawingArea_Scribble.get_style()->get_black_gc(),
+      true,
+      update_rect.get_x(), update_rect.get_y(),
+      update_rect.get_width(), update_rect.get_height());
 
-  /* Now invalidate the affected region of the drawing area. */
+  // Now invalidate the affected region of the drawing area.
   m_DrawingArea_Scribble.get_window()->invalidate_rect(update_rect, false);
 }
 
-
