@@ -25,14 +25,7 @@
 // Changed code a bit, works better but window "flashs" in the wrong
 // position.  --Karl
 //
-#include <gtkmm/main.h>
-#include <gtkmm/window.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/button.h>
-#include <gtkmm/box.h>
-#include <gtkmm/label.h>
-#include <gtkmm/eventbox.h>
-#include <gdkmm/window.h> //It's not included from gtkmm/widget.h to make compilation faster.
+#include <gtkmm.h>
 #include <iostream>
 
 using namespace Gtk;
@@ -59,14 +52,14 @@ public:
          get_window()->show();
     }
  
-  void center(gint x, gint y, gint w=-1, gint h=-1)
+  void center(int x, int y, int w=-1, int h=-1)
     {
-      gint dw,dh;
+      int dw,dh;
       if (!is_realized()) realize();
       get_window()->get_size(dw, dh);
       if (w==-1) w=x;
       if (h==-1) h=y;
-      
+
       int cx = x + w/2 - dw/2;
       int cy = y + h/2 - dh/2;
 
@@ -77,14 +70,14 @@ public:
 
   void center()
     {
-      gint w = gdk_screen_width ();
-      gint h = gdk_screen_height ();
+      int w = Gdk::screen_width();
+      int h = Gdk::screen_height();
       center(0,0,w,h);
     }
 
   void center(Gtk::Widget& widget)
     {
-      gint x, y, w, h;   
+      int x, y, w, h;
       if (!widget.is_mapped()) 
         {
           center();
@@ -164,7 +157,7 @@ public:
     mainBox->pack_start(*leftBox);
 
     Box* centralBox = manage(new VBox);
-    mainBox->pack_start(*centralBox, Gtk::FILL);
+    mainBox->pack_start(*centralBox, Gtk::PACK_SHRINK);
 
     Box* topBox = manage(new HBox);
     centralBox->pack_start(*topBox);
@@ -209,11 +202,11 @@ public:
       ->signal_clicked().connect(bind(slot(*dialog, &MyDialog::CenterOverWidget),
                              eventBox));
 
-    centralBox->pack_start(*windowManagerDecidesButton, Gtk::SHRINK);
-    centralBox->pack_start(*centerOverDisplayButton, Gtk::SHRINK);
-    centralBox->pack_start(*centerOverMouseButton, Gtk::SHRINK);
-    centralBox->pack_start(*centerOverWindowButton, Gtk::SHRINK);
-    centralBox->pack_start(*centerOverWidgetButton, Gtk::SHRINK);
+    centralBox->pack_start(*windowManagerDecidesButton, Gtk::PACK_SHRINK);
+    centralBox->pack_start(*centerOverDisplayButton, Gtk::PACK_SHRINK);
+    centralBox->pack_start(*centerOverMouseButton, Gtk::PACK_SHRINK);
+    centralBox->pack_start(*centerOverWindowButton, Gtk::PACK_SHRINK);
+    centralBox->pack_start(*centerOverWidgetButton, Gtk::PACK_SHRINK);
 
     Box* bottomBox = manage(new HBox);
     centralBox->pack_start(*bottomBox);
@@ -232,7 +225,7 @@ int main(int argc, char* argv[])
   Gtk::Main kit(argc, argv);
   MyWindow win;
   win.show_all();
-  kit.run(win);
+  Gtk::Main::run(win);
   return 0;
 }
 
