@@ -102,6 +102,7 @@
 #include "./treepath.h"
 #include "./treeselection.h"
 #include "./treesortable.h"
+#include "./treerowreference.h"
 #include "./treeiter.h"
 #include "./treemodel.h"
 #include "./treestore.h"
@@ -138,6 +139,8 @@ GType gtk_check_menu_item_get_type(void);
 GType gtk_color_selection_get_type(void);
 GType gtk_color_selection_dialog_get_type(void);
 GType gtk_combo_get_type(void);
+GType gtk_list_get_type(void);
+GType gtk_list_item_get_type(void);
 GType gtk_container_get_type(void);
 GType gtk_curve_get_type(void);
 GType gtk_dialog_get_type(void);
@@ -177,7 +180,9 @@ GType gtk_notebook_get_type(void);
 GType gtk_object_get_type(void);
 GType gtk_option_menu_get_type(void);
 GType gtk_paned_get_type(void);
+#ifndef GTKMM_WIN32
 GType gtk_plug_get_type(void);
+#endif //GTKMM_WIN32
 GType gtk_progress_bar_get_type(void);
 GType gtk_radio_button_get_type(void);
 GType gtk_radio_menu_item_get_type(void);
@@ -191,7 +196,9 @@ GType gtk_separator_get_type(void);
 GType gtk_separator_menu_item_get_type(void);
 GType gtk_settings_get_type(void);
 GType gtk_size_group_get_type(void);
+#ifndef GTKMM_WIN32
 GType gtk_socket_get_type(void);
+#endif //GTKMM_WIN32
 GType gtk_spin_button_get_type(void);
 GType gtk_statusbar_get_type(void);
 GType gtk_style_get_type(void);
@@ -249,6 +256,8 @@ namespace Gtk {  class CheckMenuItem_Class { public: static Glib::ObjectBase* wr
 namespace Gtk {  class ColorSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class ColorSelectionDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Combo_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class ComboDropDown_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class ComboDropDownItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Container_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Curve_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Dialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -288,7 +297,9 @@ namespace Gtk {  class Notebook_Class { public: static Glib::ObjectBase* wrap_ne
 namespace Gtk {  class Object_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class OptionMenu_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Paned_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#ifndef GTKMM_WIN32
 namespace Gtk {  class Plug_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //GTKMM_WIN32
 namespace Gtk {  class ProgressBar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class RadioButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class RadioMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -302,7 +313,9 @@ namespace Gtk {  class Separator_Class { public: static Glib::ObjectBase* wrap_n
 namespace Gtk {  class SeparatorMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Settings_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class SizeGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#ifndef GTKMM_WIN32
 namespace Gtk {  class Socket_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //GTKMM_WIN32
 namespace Gtk {  class SpinButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Statusbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Style_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -360,6 +373,8 @@ void wrap_init()
   Glib::wrap_register(gtk_color_selection_get_type(), &Gtk::ColorSelection_Class::wrap_new);
   Glib::wrap_register(gtk_color_selection_dialog_get_type(), &Gtk::ColorSelectionDialog_Class::wrap_new);
   Glib::wrap_register(gtk_combo_get_type(), &Gtk::Combo_Class::wrap_new);
+  Glib::wrap_register(gtk_list_get_type(), &Gtk::ComboDropDown_Class::wrap_new);
+  Glib::wrap_register(gtk_list_item_get_type(), &Gtk::ComboDropDownItem_Class::wrap_new);
   Glib::wrap_register(gtk_container_get_type(), &Gtk::Container_Class::wrap_new);
   Glib::wrap_register(gtk_curve_get_type(), &Gtk::Curve_Class::wrap_new);
   Glib::wrap_register(gtk_dialog_get_type(), &Gtk::Dialog_Class::wrap_new);
@@ -399,7 +414,9 @@ void wrap_init()
   Glib::wrap_register(gtk_object_get_type(), &Gtk::Object_Class::wrap_new);
   Glib::wrap_register(gtk_option_menu_get_type(), &Gtk::OptionMenu_Class::wrap_new);
   Glib::wrap_register(gtk_paned_get_type(), &Gtk::Paned_Class::wrap_new);
+#ifndef GTKMM_WIN32
   Glib::wrap_register(gtk_plug_get_type(), &Gtk::Plug_Class::wrap_new);
+#endif //GTKMM_WIN32
   Glib::wrap_register(gtk_progress_bar_get_type(), &Gtk::ProgressBar_Class::wrap_new);
   Glib::wrap_register(gtk_radio_button_get_type(), &Gtk::RadioButton_Class::wrap_new);
   Glib::wrap_register(gtk_radio_menu_item_get_type(), &Gtk::RadioMenuItem_Class::wrap_new);
@@ -413,7 +430,9 @@ void wrap_init()
   Glib::wrap_register(gtk_separator_menu_item_get_type(), &Gtk::SeparatorMenuItem_Class::wrap_new);
   Glib::wrap_register(gtk_settings_get_type(), &Gtk::Settings_Class::wrap_new);
   Glib::wrap_register(gtk_size_group_get_type(), &Gtk::SizeGroup_Class::wrap_new);
+#ifndef GTKMM_WIN32
   Glib::wrap_register(gtk_socket_get_type(), &Gtk::Socket_Class::wrap_new);
+#endif //GTKMM_WIN32
   Glib::wrap_register(gtk_spin_button_get_type(), &Gtk::SpinButton_Class::wrap_new);
   Glib::wrap_register(gtk_statusbar_get_type(), &Gtk::Statusbar_Class::wrap_new);
   Glib::wrap_register(gtk_style_get_type(), &Gtk::Style_Class::wrap_new);
@@ -465,6 +484,8 @@ void wrap_init()
   Gtk::ColorSelection::get_type();
   Gtk::ColorSelectionDialog::get_type();
   Gtk::Combo::get_type();
+  Gtk::ComboDropDown::get_type();
+  Gtk::ComboDropDownItem::get_type();
   Gtk::Container::get_type();
   Gtk::Curve::get_type();
   Gtk::Dialog::get_type();
@@ -504,7 +525,9 @@ void wrap_init()
   Gtk::Object::get_type();
   Gtk::OptionMenu::get_type();
   Gtk::Paned::get_type();
+#ifndef GTKMM_WIN32
   Gtk::Plug::get_type();
+#endif //GTKMM_WIN32
   Gtk::ProgressBar::get_type();
   Gtk::RadioButton::get_type();
   Gtk::RadioMenuItem::get_type();
@@ -518,7 +541,9 @@ void wrap_init()
   Gtk::SeparatorMenuItem::get_type();
   Gtk::Settings::get_type();
   Gtk::SizeGroup::get_type();
+#ifndef GTKMM_WIN32
   Gtk::Socket::get_type();
+#endif //GTKMM_WIN32
   Gtk::SpinButton::get_type();
   Gtk::Statusbar::get_type();
   Gtk::Style::get_type();
