@@ -115,6 +115,9 @@ sub output_wrap_vfunc_cc($$$$$$)
 
   #Use a different macro for Interfaces, to generate an extra convenience method.
 
+  my $refreturn = "";
+  $refreturn = "refreturn" if($$objCppfunc{rettype_needs_ref});
+
   my $str = sprintf("_VFUNC_CC(%s,%s,%s,%s,\`%s\',\`%s\',%s)dnl\n",
     $$objCppfunc{name},
     $cname,
@@ -122,8 +125,8 @@ sub output_wrap_vfunc_cc($$$$$$)
     $$objDefsSignal{rettype},
     $objCppfunc->args_types_and_names(),
     convert_args_cpp_to_c($objCppfunc, $objDefsSignal, 0, $line_num), #$objCppfunc->args_names_only(),
-    $$objCppfunc{const}
-  );
+    $refreturn);
+
   $self->append($str);
 
   # e.g. Gtk::ButtonClass::draw_indicator():
@@ -137,6 +140,7 @@ sub output_wrap_vfunc_cc($$$$$$)
     $objDefsSignal->args_names_only(),
     convert_args_c_to_cpp($objDefsSignal, $objCppfunc, $line_num),
     ${$objDefsSignal->get_param_names()}[0]);
+
   $self->append($str);
 }
 
